@@ -21,10 +21,12 @@ class Algorithm(AbstractApiClass):
             configOptions (dict): Map dataset types and configs to train function parameter names
             algorithmId (str): The unique identifier of the algorithm
             useGpu (bool): Whether to use gpu for model training
+            algorithmTrainingConfig (dict): The algorithm specific training config
+            onlyOfflineDeployable (bool): Whether or not the algorithm is only allowed to be deployed offline
             codeSource (CodeSource): Info about the source code of the algorithm
     """
 
-    def __init__(self, client, name=None, problemType=None, createdAt=None, updatedAt=None, isDefaultEnabled=None, trainingInputMappings=None, trainFunctionName=None, predictFunctionName=None, predictManyFunctionName=None, initializeFunctionName=None, configOptions=None, algorithmId=None, useGpu=None, codeSource={}):
+    def __init__(self, client, name=None, problemType=None, createdAt=None, updatedAt=None, isDefaultEnabled=None, trainingInputMappings=None, trainFunctionName=None, predictFunctionName=None, predictManyFunctionName=None, initializeFunctionName=None, configOptions=None, algorithmId=None, useGpu=None, algorithmTrainingConfig=None, onlyOfflineDeployable=None, codeSource={}):
         super().__init__(client, algorithmId)
         self.name = name
         self.problem_type = problemType
@@ -39,10 +41,18 @@ class Algorithm(AbstractApiClass):
         self.config_options = configOptions
         self.algorithm_id = algorithmId
         self.use_gpu = useGpu
+        self.algorithm_training_config = algorithmTrainingConfig
+        self.only_offline_deployable = onlyOfflineDeployable
         self.code_source = client._build_class(CodeSource, codeSource)
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"Algorithm(name={repr(self.name)},\n  problem_type={repr(self.problem_type)},\n  created_at={repr(self.created_at)},\n  updated_at={repr(self.updated_at)},\n  is_default_enabled={repr(self.is_default_enabled)},\n  training_input_mappings={repr(self.training_input_mappings)},\n  train_function_name={repr(self.train_function_name)},\n  predict_function_name={repr(self.predict_function_name)},\n  predict_many_function_name={repr(self.predict_many_function_name)},\n  initialize_function_name={repr(self.initialize_function_name)},\n  config_options={repr(self.config_options)},\n  algorithm_id={repr(self.algorithm_id)},\n  use_gpu={repr(self.use_gpu)},\n  code_source={repr(self.code_source)})"
+        repr_dict = {f'name': repr(self.name), f'problem_type': repr(self.problem_type), f'created_at': repr(self.created_at), f'updated_at': repr(self.updated_at), f'is_default_enabled': repr(self.is_default_enabled), f'training_input_mappings': repr(self.training_input_mappings), f'train_function_name': repr(self.train_function_name), f'predict_function_name': repr(self.predict_function_name), f'predict_many_function_name': repr(
+            self.predict_many_function_name), f'initialize_function_name': repr(self.initialize_function_name), f'config_options': repr(self.config_options), f'algorithm_id': repr(self.algorithm_id), f'use_gpu': repr(self.use_gpu), f'algorithm_training_config': repr(self.algorithm_training_config), f'only_offline_deployable': repr(self.only_offline_deployable), f'code_source': repr(self.code_source)}
+        class_name = "Algorithm"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -51,4 +61,6 @@ class Algorithm(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'name': self.name, 'problem_type': self.problem_type, 'created_at': self.created_at, 'updated_at': self.updated_at, 'is_default_enabled': self.is_default_enabled, 'training_input_mappings': self.training_input_mappings, 'train_function_name': self.train_function_name, 'predict_function_name': self.predict_function_name, 'predict_many_function_name': self.predict_many_function_name, 'initialize_function_name': self.initialize_function_name, 'config_options': self.config_options, 'algorithm_id': self.algorithm_id, 'use_gpu': self.use_gpu, 'code_source': self._get_attribute_as_dict(self.code_source)}
+        resp = {'name': self.name, 'problem_type': self.problem_type, 'created_at': self.created_at, 'updated_at': self.updated_at, 'is_default_enabled': self.is_default_enabled, 'training_input_mappings': self.training_input_mappings, 'train_function_name': self.train_function_name, 'predict_function_name': self.predict_function_name, 'predict_many_function_name':
+                self.predict_many_function_name, 'initialize_function_name': self.initialize_function_name, 'config_options': self.config_options, 'algorithm_id': self.algorithm_id, 'use_gpu': self.use_gpu, 'algorithm_training_config': self.algorithm_training_config, 'only_offline_deployable': self.only_offline_deployable, 'code_source': self._get_attribute_as_dict(self.code_source)}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
