@@ -17,9 +17,15 @@ class CategoricalRangeViolation(AbstractApiClass):
         self.name = name
         self.most_common_values = mostCommonValues
         self.freq_outside_training_range = freqOutsideTrainingRange
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"CategoricalRangeViolation(name={repr(self.name)},\n  most_common_values={repr(self.most_common_values)},\n  freq_outside_training_range={repr(self.freq_outside_training_range)})"
+        repr_dict = {f'name': repr(self.name), f'most_common_values': repr(
+            self.most_common_values), f'freq_outside_training_range': repr(self.freq_outside_training_range)}
+        class_name = "CategoricalRangeViolation"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -28,4 +34,6 @@ class CategoricalRangeViolation(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'name': self.name, 'most_common_values': self.most_common_values, 'freq_outside_training_range': self.freq_outside_training_range}
+        resp = {'name': self.name, 'most_common_values': self.most_common_values,
+                'freq_outside_training_range': self.freq_outside_training_range}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
