@@ -19,9 +19,15 @@ class ConcatenationConfig(AbstractApiClass):
         self.merge_type = mergeType
         self.replace_until_timestamp = replaceUntilTimestamp
         self.skip_materialize = skipMaterialize
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"ConcatenationConfig(concatenated_table={repr(self.concatenated_table)},\n  merge_type={repr(self.merge_type)},\n  replace_until_timestamp={repr(self.replace_until_timestamp)},\n  skip_materialize={repr(self.skip_materialize)})"
+        repr_dict = {f'concatenated_table': repr(self.concatenated_table), f'merge_type': repr(
+            self.merge_type), f'replace_until_timestamp': repr(self.replace_until_timestamp), f'skip_materialize': repr(self.skip_materialize)}
+        class_name = "ConcatenationConfig"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -30,4 +36,6 @@ class ConcatenationConfig(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'concatenated_table': self.concatenated_table, 'merge_type': self.merge_type, 'replace_until_timestamp': self.replace_until_timestamp, 'skip_materialize': self.skip_materialize}
+        resp = {'concatenated_table': self.concatenated_table, 'merge_type': self.merge_type,
+                'replace_until_timestamp': self.replace_until_timestamp, 'skip_materialize': self.skip_materialize}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
