@@ -24,9 +24,15 @@ class CustomLossFunction(AbstractApiClass):
         self.loss_function_name = lossFunctionName
         self.loss_function_type = lossFunctionType
         self.code_source = client._build_class(CodeSource, codeSource)
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"CustomLossFunction(notebook_id={repr(self.notebook_id)},\n  name={repr(self.name)},\n  created_at={repr(self.created_at)},\n  loss_function_name={repr(self.loss_function_name)},\n  loss_function_type={repr(self.loss_function_type)},\n  code_source={repr(self.code_source)})"
+        repr_dict = {f'notebook_id': repr(self.notebook_id), f'name': repr(self.name), f'created_at': repr(self.created_at), f'loss_function_name': repr(
+            self.loss_function_name), f'loss_function_type': repr(self.loss_function_type), f'code_source': repr(self.code_source)}
+        class_name = "CustomLossFunction"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -35,4 +41,6 @@ class CustomLossFunction(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'notebook_id': self.notebook_id, 'name': self.name, 'created_at': self.created_at, 'loss_function_name': self.loss_function_name, 'loss_function_type': self.loss_function_type, 'code_source': self._get_attribute_as_dict(self.code_source)}
+        resp = {'notebook_id': self.notebook_id, 'name': self.name, 'created_at': self.created_at, 'loss_function_name': self.loss_function_name,
+                'loss_function_type': self.loss_function_type, 'code_source': self._get_attribute_as_dict(self.code_source)}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
