@@ -25,9 +25,15 @@ class CustomMetric(AbstractApiClass):
         self.notebook_id = notebookId
         self.latest_custom_metric_version = client._build_class(
             CustomMetricVersion, latestCustomMetricVersion)
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"CustomMetric(custom_metric_id={repr(self.custom_metric_id)},\n  name={repr(self.name)},\n  created_at={repr(self.created_at)},\n  problem_type={repr(self.problem_type)},\n  notebook_id={repr(self.notebook_id)},\n  latest_custom_metric_version={repr(self.latest_custom_metric_version)})"
+        repr_dict = {f'custom_metric_id': repr(self.custom_metric_id), f'name': repr(self.name), f'created_at': repr(self.created_at), f'problem_type': repr(
+            self.problem_type), f'notebook_id': repr(self.notebook_id), f'latest_custom_metric_version': repr(self.latest_custom_metric_version)}
+        class_name = "CustomMetric"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -36,4 +42,6 @@ class CustomMetric(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'custom_metric_id': self.custom_metric_id, 'name': self.name, 'created_at': self.created_at, 'problem_type': self.problem_type, 'notebook_id': self.notebook_id, 'latest_custom_metric_version': self._get_attribute_as_dict(self.latest_custom_metric_version)}
+        resp = {'custom_metric_id': self.custom_metric_id, 'name': self.name, 'created_at': self.created_at, 'problem_type': self.problem_type,
+                'notebook_id': self.notebook_id, 'latest_custom_metric_version': self._get_attribute_as_dict(self.latest_custom_metric_version)}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
