@@ -22,9 +22,15 @@ class CustomMetricVersion(AbstractApiClass):
         self.created_at = createdAt
         self.custom_metric_function_name = customMetricFunctionName
         self.code_source = client._build_class(CodeSource, codeSource)
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"CustomMetricVersion(custom_metric_version={repr(self.custom_metric_version)},\n  name={repr(self.name)},\n  created_at={repr(self.created_at)},\n  custom_metric_function_name={repr(self.custom_metric_function_name)},\n  code_source={repr(self.code_source)})"
+        repr_dict = {f'custom_metric_version': repr(self.custom_metric_version), f'name': repr(self.name), f'created_at': repr(
+            self.created_at), f'custom_metric_function_name': repr(self.custom_metric_function_name), f'code_source': repr(self.code_source)}
+        class_name = "CustomMetricVersion"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -33,7 +39,9 @@ class CustomMetricVersion(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'custom_metric_version': self.custom_metric_version, 'name': self.name, 'created_at': self.created_at, 'custom_metric_function_name': self.custom_metric_function_name, 'code_source': self._get_attribute_as_dict(self.code_source)}
+        resp = {'custom_metric_version': self.custom_metric_version, 'name': self.name, 'created_at': self.created_at,
+                'custom_metric_function_name': self.custom_metric_function_name, 'code_source': self._get_attribute_as_dict(self.code_source)}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
 
     def refresh(self):
         """
