@@ -19,9 +19,15 @@ class CustomTrainFunctionInfo(AbstractApiClass):
         self.schema_mappings = schemaMappings
         self.train_data_parameter_to_feature_group_ids = trainDataParameterToFeatureGroupIds
         self.training_config = trainingConfig
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"CustomTrainFunctionInfo(training_data_parameter_name_mapping={repr(self.training_data_parameter_name_mapping)},\n  schema_mappings={repr(self.schema_mappings)},\n  train_data_parameter_to_feature_group_ids={repr(self.train_data_parameter_to_feature_group_ids)},\n  training_config={repr(self.training_config)})"
+        repr_dict = {f'training_data_parameter_name_mapping': repr(self.training_data_parameter_name_mapping), f'schema_mappings': repr(
+            self.schema_mappings), f'train_data_parameter_to_feature_group_ids': repr(self.train_data_parameter_to_feature_group_ids), f'training_config': repr(self.training_config)}
+        class_name = "CustomTrainFunctionInfo"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -30,4 +36,6 @@ class CustomTrainFunctionInfo(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'training_data_parameter_name_mapping': self.training_data_parameter_name_mapping, 'schema_mappings': self.schema_mappings, 'train_data_parameter_to_feature_group_ids': self.train_data_parameter_to_feature_group_ids, 'training_config': self.training_config}
+        resp = {'training_data_parameter_name_mapping': self.training_data_parameter_name_mapping, 'schema_mappings': self.schema_mappings,
+                'train_data_parameter_to_feature_group_ids': self.train_data_parameter_to_feature_group_ids, 'training_config': self.training_config}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
