@@ -17,9 +17,15 @@ class DataConsistencyDuplication(AbstractApiClass):
         self.total_count = totalCount
         self.num_duplicates = numDuplicates
         self.sample = client._build_class(FeatureRecord, sample)
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"DataConsistencyDuplication(total_count={repr(self.total_count)},\n  num_duplicates={repr(self.num_duplicates)},\n  sample={repr(self.sample)})"
+        repr_dict = {f'total_count': repr(self.total_count), f'num_duplicates': repr(
+            self.num_duplicates), f'sample': repr(self.sample)}
+        class_name = "DataConsistencyDuplication"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -28,4 +34,6 @@ class DataConsistencyDuplication(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'total_count': self.total_count, 'num_duplicates': self.num_duplicates, 'sample': self._get_attribute_as_dict(self.sample)}
+        resp = {'total_count': self.total_count, 'num_duplicates': self.num_duplicates,
+                'sample': self._get_attribute_as_dict(self.sample)}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
