@@ -13,9 +13,14 @@ class DataPrepLogs(AbstractApiClass):
     def __init__(self, client, logs=None):
         super().__init__(client, None)
         self.logs = logs
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"DataPrepLogs(logs={repr(self.logs)})"
+        repr_dict = {f'logs': repr(self.logs)}
+        class_name = "DataPrepLogs"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -24,4 +29,5 @@ class DataPrepLogs(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'logs': self.logs}
+        resp = {'logs': self.logs}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
