@@ -13,9 +13,14 @@ class DataQualityResults(AbstractApiClass):
     def __init__(self, client, results=None):
         super().__init__(client, None)
         self.results = results
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"DataQualityResults(results={repr(self.results)})"
+        repr_dict = {f'results': repr(self.results)}
+        class_name = "DataQualityResults"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -24,4 +29,5 @@ class DataQualityResults(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'results': self.results}
+        resp = {'results': self.results}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
