@@ -23,9 +23,15 @@ class DatabaseConnector(AbstractApiClass):
         self.status = status
         self.auth = auth
         self.created_at = createdAt
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"DatabaseConnector(database_connector_id={repr(self.database_connector_id)},\n  service={repr(self.service)},\n  name={repr(self.name)},\n  status={repr(self.status)},\n  auth={repr(self.auth)},\n  created_at={repr(self.created_at)})"
+        repr_dict = {f'database_connector_id': repr(self.database_connector_id), f'service': repr(self.service), f'name': repr(
+            self.name), f'status': repr(self.status), f'auth': repr(self.auth), f'created_at': repr(self.created_at)}
+        class_name = "DatabaseConnector"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -34,25 +40,31 @@ class DatabaseConnector(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'database_connector_id': self.database_connector_id, 'service': self.service, 'name': self.name, 'status': self.status, 'auth': self.auth, 'created_at': self.created_at}
+        resp = {'database_connector_id': self.database_connector_id, 'service': self.service,
+                'name': self.name, 'status': self.status, 'auth': self.auth, 'created_at': self.created_at}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
 
-    def list_objects(self):
+    def list_objects(self, fetch_raw_data: bool = False):
         """
         Lists querable objects in the database connector.
 
         Args:
-            database_connector_id (str): Unique string identifier for the database connector.
+            fetch_raw_data (bool): If true, return unfiltered objects.
         """
-        return self.client.list_database_connector_objects(self.database_connector_id)
+        return self.client.list_database_connector_objects(self.database_connector_id, fetch_raw_data)
 
-    def get_object_schema(self, object_name: str = None):
+    def get_object_schema(self, object_name: str = None, fetch_raw_data: bool = False):
         """
         Get the schema of an object in an database connector.
 
         Args:
             object_name (str): Unique identifier for the object in the external system.
+            fetch_raw_data (bool): If true, return unfiltered list of columns.
+
+        Returns:
+            DatabaseConnectorSchema: The schema of the object.
         """
-        return self.client.get_database_connector_object_schema(self.database_connector_id, object_name)
+        return self.client.get_database_connector_object_schema(self.database_connector_id, object_name, fetch_raw_data)
 
     def rename(self, name: str):
         """
@@ -80,3 +92,24 @@ class DatabaseConnector(AbstractApiClass):
             database_connector_id (str): The unique identifier for the database connector.
         """
         return self.client.delete_database_connector(self.database_connector_id)
+
+    def query(self, query: str):
+        """
+        Runs a query in the specified database connector.
+
+        Args:
+            query (str): The query to be run in the database connector.
+        """
+        return self.client.query_database_connector(self.database_connector_id, query)
+
+    def get_auth(self):
+        """
+        Get the authentication details for a given database connector.
+
+        Args:
+            database_connector_id (str): The unique ID associated with the database connector.
+
+        Returns:
+            DatabaseConnector: The database connector with the authentication details.
+        """
+        return self.client.get_database_connector_auth(self.database_connector_id)
