@@ -8,7 +8,7 @@ class DatasetColumn(AbstractApiClass):
         Args:
             client (ApiClient): An authenticated API Client instance
             name (str): The unique name of the column.
-            dataType (str): The underlying data type of each column. Refer to the [guide on data types](DATA_TYPES_URL) for more information.
+            dataType (str): The underlying data type of each column.
             detectedDataType (str): The detected data type of the column.
             featureType (str): Feature type of the column.
             detectedFeatureType (str): The detected feature type of the column.
@@ -29,9 +29,15 @@ class DatasetColumn(AbstractApiClass):
         self.valid_data_types = validDataTypes
         self.time_format = timeFormat
         self.timestamp_frequency = timestampFrequency
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"DatasetColumn(name={repr(self.name)},\n  data_type={repr(self.data_type)},\n  detected_data_type={repr(self.detected_data_type)},\n  feature_type={repr(self.feature_type)},\n  detected_feature_type={repr(self.detected_feature_type)},\n  original_name={repr(self.original_name)},\n  valid_data_types={repr(self.valid_data_types)},\n  time_format={repr(self.time_format)},\n  timestamp_frequency={repr(self.timestamp_frequency)})"
+        repr_dict = {f'name': repr(self.name), f'data_type': repr(self.data_type), f'detected_data_type': repr(self.detected_data_type), f'feature_type': repr(self.feature_type), f'detected_feature_type': repr(
+            self.detected_feature_type), f'original_name': repr(self.original_name), f'valid_data_types': repr(self.valid_data_types), f'time_format': repr(self.time_format), f'timestamp_frequency': repr(self.timestamp_frequency)}
+        class_name = "DatasetColumn"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -40,4 +46,6 @@ class DatasetColumn(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'name': self.name, 'data_type': self.data_type, 'detected_data_type': self.detected_data_type, 'feature_type': self.feature_type, 'detected_feature_type': self.detected_feature_type, 'original_name': self.original_name, 'valid_data_types': self.valid_data_types, 'time_format': self.time_format, 'timestamp_frequency': self.timestamp_frequency}
+        resp = {'name': self.name, 'data_type': self.data_type, 'detected_data_type': self.detected_data_type, 'feature_type': self.feature_type, 'detected_feature_type': self.detected_feature_type,
+                'original_name': self.original_name, 'valid_data_types': self.valid_data_types, 'time_format': self.time_format, 'timestamp_frequency': self.timestamp_frequency}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
