@@ -17,9 +17,15 @@ class DeploymentAuthToken(AbstractApiClass):
         self.deployment_token = deploymentToken
         self.created_at = createdAt
         self.name = name
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"DeploymentAuthToken(deployment_token={repr(self.deployment_token)},\n  created_at={repr(self.created_at)},\n  name={repr(self.name)})"
+        repr_dict = {f'deployment_token': repr(self.deployment_token), f'created_at': repr(
+            self.created_at), f'name': repr(self.name)}
+        class_name = "DeploymentAuthToken"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -28,4 +34,6 @@ class DeploymentAuthToken(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'deployment_token': self.deployment_token, 'created_at': self.created_at, 'name': self.name}
+        resp = {'deployment_token': self.deployment_token,
+                'created_at': self.created_at, 'name': self.name}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
