@@ -15,9 +15,15 @@ class EdaChartDescription(AbstractApiClass):
         super().__init__(client, None)
         self.chart_type = chartType
         self.description = description
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"EdaChartDescription(chart_type={repr(self.chart_type)},\n  description={repr(self.description)})"
+        repr_dict = {f'chart_type': repr(
+            self.chart_type), f'description': repr(self.description)}
+        class_name = "EdaChartDescription"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -26,4 +32,5 @@ class EdaChartDescription(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'chart_type': self.chart_type, 'description': self.description}
+        resp = {'chart_type': self.chart_type, 'description': self.description}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
