@@ -42,9 +42,15 @@ class Feature(AbstractApiClass):
         self.columns = client._build_class(NestedFeature, columns)
         self.point_in_time_info = client._build_class(
             PointInTimeFeature, pointInTimeInfo)
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"Feature(name={repr(self.name)},\n  select_clause={repr(self.select_clause)},\n  feature_mapping={repr(self.feature_mapping)},\n  source_table={repr(self.source_table)},\n  original_name={repr(self.original_name)},\n  using_clause={repr(self.using_clause)},\n  order_clause={repr(self.order_clause)},\n  where_clause={repr(self.where_clause)},\n  feature_type={repr(self.feature_type)},\n  data_type={repr(self.data_type)},\n  detected_feature_type={repr(self.detected_feature_type)},\n  detected_data_type={repr(self.detected_data_type)},\n  columns={repr(self.columns)},\n  point_in_time_info={repr(self.point_in_time_info)})"
+        repr_dict = {f'name': repr(self.name), f'select_clause': repr(self.select_clause), f'feature_mapping': repr(self.feature_mapping), f'source_table': repr(self.source_table), f'original_name': repr(self.original_name), f'using_clause': repr(self.using_clause), f'order_clause': repr(self.order_clause), f'where_clause': repr(
+            self.where_clause), f'feature_type': repr(self.feature_type), f'data_type': repr(self.data_type), f'detected_feature_type': repr(self.detected_feature_type), f'detected_data_type': repr(self.detected_data_type), f'columns': repr(self.columns), f'point_in_time_info': repr(self.point_in_time_info)}
+        class_name = "Feature"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -53,4 +59,6 @@ class Feature(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'name': self.name, 'select_clause': self.select_clause, 'feature_mapping': self.feature_mapping, 'source_table': self.source_table, 'original_name': self.original_name, 'using_clause': self.using_clause, 'order_clause': self.order_clause, 'where_clause': self.where_clause, 'feature_type': self.feature_type, 'data_type': self.data_type, 'detected_feature_type': self.detected_feature_type, 'detected_data_type': self.detected_data_type, 'columns': self._get_attribute_as_dict(self.columns), 'point_in_time_info': self._get_attribute_as_dict(self.point_in_time_info)}
+        resp = {'name': self.name, 'select_clause': self.select_clause, 'feature_mapping': self.feature_mapping, 'source_table': self.source_table, 'original_name': self.original_name, 'using_clause': self.using_clause, 'order_clause': self.order_clause, 'where_clause': self.where_clause,
+                'feature_type': self.feature_type, 'data_type': self.data_type, 'detected_feature_type': self.detected_feature_type, 'detected_data_type': self.detected_data_type, 'columns': self._get_attribute_as_dict(self.columns), 'point_in_time_info': self._get_attribute_as_dict(self.point_in_time_info)}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
