@@ -1,3 +1,4 @@
+from .project_config import ProjectConfig
 from .return_class import AbstractApiClass
 
 
@@ -8,6 +9,8 @@ class FeatureGroupExport(AbstractApiClass):
         Args:
             client (ApiClient): An authenticated API Client instance
             featureGroupExportId (str): Unique identifier for this export.
+            failedWrites (int): Number of failed writes.
+            totalWrites (int): Total number of writes.
             featureGroupVersion (str): Version of the feature group being exported.
             connectorType (str): The type of connector
             outputLocation (str): File Connector location the feature group is being written to.
@@ -23,12 +26,14 @@ class FeatureGroupExport(AbstractApiClass):
             additionalIdColumns (list[str]): For database connectors which support it, additional ID columns to use as a complex key for upserting.
             error (str): If `status` is `FAILED`, this field will be populated with an error.
             databaseOutputError (bool): If `True`, there were errors reported by the database connector while writing.
-            projectConfig (dict): Project config for this feature group.
+            projectConfig (ProjectConfig): Project config for this feature group.
     """
 
-    def __init__(self, client, featureGroupExportId=None, featureGroupVersion=None, connectorType=None, outputLocation=None, fileFormat=None, databaseConnectorId=None, objectName=None, writeMode=None, databaseFeatureMapping=None, idColumn=None, status=None, createdAt=None, exportCompletedAt=None, additionalIdColumns=None, error=None, databaseOutputError=None, projectConfig=None):
+    def __init__(self, client, featureGroupExportId=None, failedWrites=None, totalWrites=None, featureGroupVersion=None, connectorType=None, outputLocation=None, fileFormat=None, databaseConnectorId=None, objectName=None, writeMode=None, databaseFeatureMapping=None, idColumn=None, status=None, createdAt=None, exportCompletedAt=None, additionalIdColumns=None, error=None, databaseOutputError=None, projectConfig={}):
         super().__init__(client, featureGroupExportId)
         self.feature_group_export_id = featureGroupExportId
+        self.failed_writes = failedWrites
+        self.total_writes = totalWrites
         self.feature_group_version = featureGroupVersion
         self.connector_type = connectorType
         self.output_location = outputLocation
@@ -44,10 +49,16 @@ class FeatureGroupExport(AbstractApiClass):
         self.additional_id_columns = additionalIdColumns
         self.error = error
         self.database_output_error = databaseOutputError
-        self.project_config = projectConfig
+        self.project_config = client._build_class(ProjectConfig, projectConfig)
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"FeatureGroupExport(feature_group_export_id={repr(self.feature_group_export_id)},\n  feature_group_version={repr(self.feature_group_version)},\n  connector_type={repr(self.connector_type)},\n  output_location={repr(self.output_location)},\n  file_format={repr(self.file_format)},\n  database_connector_id={repr(self.database_connector_id)},\n  object_name={repr(self.object_name)},\n  write_mode={repr(self.write_mode)},\n  database_feature_mapping={repr(self.database_feature_mapping)},\n  id_column={repr(self.id_column)},\n  status={repr(self.status)},\n  created_at={repr(self.created_at)},\n  export_completed_at={repr(self.export_completed_at)},\n  additional_id_columns={repr(self.additional_id_columns)},\n  error={repr(self.error)},\n  database_output_error={repr(self.database_output_error)},\n  project_config={repr(self.project_config)})"
+        repr_dict = {f'feature_group_export_id': repr(self.feature_group_export_id), f'failed_writes': repr(self.failed_writes), f'total_writes': repr(self.total_writes), f'feature_group_version': repr(self.feature_group_version), f'connector_type': repr(self.connector_type), f'output_location': repr(self.output_location), f'file_format': repr(self.file_format), f'database_connector_id': repr(self.database_connector_id), f'object_name': repr(self.object_name), f'write_mode': repr(
+            self.write_mode), f'database_feature_mapping': repr(self.database_feature_mapping), f'id_column': repr(self.id_column), f'status': repr(self.status), f'created_at': repr(self.created_at), f'export_completed_at': repr(self.export_completed_at), f'additional_id_columns': repr(self.additional_id_columns), f'error': repr(self.error), f'database_output_error': repr(self.database_output_error), f'project_config': repr(self.project_config)}
+        class_name = "FeatureGroupExport"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -56,7 +67,9 @@ class FeatureGroupExport(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'feature_group_export_id': self.feature_group_export_id, 'feature_group_version': self.feature_group_version, 'connector_type': self.connector_type, 'output_location': self.output_location, 'file_format': self.file_format, 'database_connector_id': self.database_connector_id, 'object_name': self.object_name, 'write_mode': self.write_mode, 'database_feature_mapping': self.database_feature_mapping, 'id_column': self.id_column, 'status': self.status, 'created_at': self.created_at, 'export_completed_at': self.export_completed_at, 'additional_id_columns': self.additional_id_columns, 'error': self.error, 'database_output_error': self.database_output_error, 'project_config': self.project_config}
+        resp = {'feature_group_export_id': self.feature_group_export_id, 'failed_writes': self.failed_writes, 'total_writes': self.total_writes, 'feature_group_version': self.feature_group_version, 'connector_type': self.connector_type, 'output_location': self.output_location, 'file_format': self.file_format, 'database_connector_id': self.database_connector_id, 'object_name': self.object_name,
+                'write_mode': self.write_mode, 'database_feature_mapping': self.database_feature_mapping, 'id_column': self.id_column, 'status': self.status, 'created_at': self.created_at, 'export_completed_at': self.export_completed_at, 'additional_id_columns': self.additional_id_columns, 'error': self.error, 'database_output_error': self.database_output_error, 'project_config': self._get_attribute_as_dict(self.project_config)}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
 
     def get_feature_group_version_export_download_url(self):
         """
@@ -106,10 +119,19 @@ class FeatureGroupExport(AbstractApiClass):
         A waiting call until feature group export is created.
 
         Args:
-            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
+            timeout (int): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
         """
         return self.client._poll(self, {'PENDING', 'EXPORTING'}, timeout=timeout)
 
+    def wait_for_export(self, timeout=3600):
+        """
+        A waiting call until feature group export is created.
+
+        Args:
+            timeout (int): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
+        """
+        return self.wait_for_results(timeout=timeout)
+
     def get_status(self):
         """
         Gets the status of the feature group export.
@@ -118,7 +140,3 @@ class FeatureGroupExport(AbstractApiClass):
             str: A string describing the status of a feature group export (pending, complete, etc.).
         """
         return self.describe().status
-
-    # to be deleted
-    def get_results(self):
-        return self.client.get_export_result(self.feature_group_export_id)
