@@ -15,9 +15,15 @@ class FeatureGroupExportDownloadUrl(AbstractApiClass):
         super().__init__(client, None)
         self.download_url = downloadUrl
         self.expires_at = expiresAt
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"FeatureGroupExportDownloadUrl(download_url={repr(self.download_url)},\n  expires_at={repr(self.expires_at)})"
+        repr_dict = {f'download_url': repr(
+            self.download_url), f'expires_at': repr(self.expires_at)}
+        class_name = "FeatureGroupExportDownloadUrl"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -26,4 +32,6 @@ class FeatureGroupExportDownloadUrl(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'download_url': self.download_url, 'expires_at': self.expires_at}
+        resp = {'download_url': self.download_url,
+                'expires_at': self.expires_at}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
