@@ -15,9 +15,15 @@ class FeatureGroupLineage(AbstractApiClass):
         super().__init__(client, None)
         self.nodes = nodes
         self.connections = connections
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"FeatureGroupLineage(nodes={repr(self.nodes)},\n  connections={repr(self.connections)})"
+        repr_dict = {f'nodes': repr(self.nodes),
+                     f'connections': repr(self.connections)}
+        class_name = "FeatureGroupLineage"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -26,4 +32,5 @@ class FeatureGroupLineage(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'nodes': self.nodes, 'connections': self.connections}
+        resp = {'nodes': self.nodes, 'connections': self.connections}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
