@@ -15,9 +15,15 @@ class FeatureGroupTemplateVariableOptions(AbstractApiClass):
         super().__init__(client, None)
         self.template_variable_options = templateVariableOptions
         self.user_feedback = userFeedback
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"FeatureGroupTemplateVariableOptions(template_variable_options={repr(self.template_variable_options)},\n  user_feedback={repr(self.user_feedback)})"
+        repr_dict = {f'template_variable_options': repr(
+            self.template_variable_options), f'user_feedback': repr(self.user_feedback)}
+        class_name = "FeatureGroupTemplateVariableOptions"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -26,4 +32,6 @@ class FeatureGroupTemplateVariableOptions(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'template_variable_options': self.template_variable_options, 'user_feedback': self.user_feedback}
+        resp = {'template_variable_options': self.template_variable_options,
+                'user_feedback': self.user_feedback}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
