@@ -17,9 +17,15 @@ class FileConnectorInstructions(AbstractApiClass):
         self.verified = verified
         self.write_permission = writePermission
         self.auth_options = authOptions
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"FileConnectorInstructions(verified={repr(self.verified)},\n  write_permission={repr(self.write_permission)},\n  auth_options={repr(self.auth_options)})"
+        repr_dict = {f'verified': repr(self.verified), f'write_permission': repr(
+            self.write_permission), f'auth_options': repr(self.auth_options)}
+        class_name = "FileConnectorInstructions"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -28,4 +34,6 @@ class FileConnectorInstructions(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'verified': self.verified, 'write_permission': self.write_permission, 'auth_options': self.auth_options}
+        resp = {'verified': self.verified, 'write_permission': self.write_permission,
+                'auth_options': self.auth_options}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
