@@ -15,9 +15,15 @@ class FileConnectorVerification(AbstractApiClass):
         super().__init__(client, None)
         self.verified = verified
         self.write_permission = writePermission
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"FileConnectorVerification(verified={repr(self.verified)},\n  write_permission={repr(self.write_permission)})"
+        repr_dict = {f'verified': repr(
+            self.verified), f'write_permission': repr(self.write_permission)}
+        class_name = "FileConnectorVerification"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -26,4 +32,6 @@ class FileConnectorVerification(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'verified': self.verified, 'write_permission': self.write_permission}
+        resp = {'verified': self.verified,
+                'write_permission': self.write_permission}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
