@@ -19,9 +19,15 @@ class GeneratedPitFeatureConfigOption(AbstractApiClass):
         self.display_name = displayName
         self.default = default
         self.description = description
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"GeneratedPitFeatureConfigOption(name={repr(self.name)},\n  display_name={repr(self.display_name)},\n  default={repr(self.default)},\n  description={repr(self.description)})"
+        repr_dict = {f'name': repr(self.name), f'display_name': repr(
+            self.display_name), f'default': repr(self.default), f'description': repr(self.description)}
+        class_name = "GeneratedPitFeatureConfigOption"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -30,4 +36,6 @@ class GeneratedPitFeatureConfigOption(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'name': self.name, 'display_name': self.display_name, 'default': self.default, 'description': self.description}
+        resp = {'name': self.name, 'display_name': self.display_name,
+                'default': self.default, 'description': self.description}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
