@@ -1,3 +1,5 @@
+from typing import List
+
 from .return_class import AbstractApiClass
 
 
@@ -15,9 +17,10 @@ class GraphDashboard(AbstractApiClass):
             plotReferenceIds (list[str]): List of the graph reference IDs for the plots to the dashboard.
             pythonFunctionNames (list[str]): List of names of each of the plots to the dashboard.
             projectName (str): The name the graph dashboard belongs to.
+            description (str): The description of the graph dashboard.
     """
 
-    def __init__(self, client, name=None, graphDashboardId=None, createdAt=None, projectId=None, pythonFunctionIds=None, plotReferenceIds=None, pythonFunctionNames=None, projectName=None):
+    def __init__(self, client, name=None, graphDashboardId=None, createdAt=None, projectId=None, pythonFunctionIds=None, plotReferenceIds=None, pythonFunctionNames=None, projectName=None, description=None):
         super().__init__(client, graphDashboardId)
         self.name = name
         self.graph_dashboard_id = graphDashboardId
@@ -27,9 +30,16 @@ class GraphDashboard(AbstractApiClass):
         self.plot_reference_ids = plotReferenceIds
         self.python_function_names = pythonFunctionNames
         self.project_name = projectName
+        self.description = description
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"GraphDashboard(name={repr(self.name)},\n  graph_dashboard_id={repr(self.graph_dashboard_id)},\n  created_at={repr(self.created_at)},\n  project_id={repr(self.project_id)},\n  python_function_ids={repr(self.python_function_ids)},\n  plot_reference_ids={repr(self.plot_reference_ids)},\n  python_function_names={repr(self.python_function_names)},\n  project_name={repr(self.project_name)})"
+        repr_dict = {f'name': repr(self.name), f'graph_dashboard_id': repr(self.graph_dashboard_id), f'created_at': repr(self.created_at), f'project_id': repr(self.project_id), f'python_function_ids': repr(
+            self.python_function_ids), f'plot_reference_ids': repr(self.plot_reference_ids), f'python_function_names': repr(self.python_function_names), f'project_name': repr(self.project_name), f'description': repr(self.description)}
+        class_name = "GraphDashboard"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -38,7 +48,9 @@ class GraphDashboard(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'name': self.name, 'graph_dashboard_id': self.graph_dashboard_id, 'created_at': self.created_at, 'project_id': self.project_id, 'python_function_ids': self.python_function_ids, 'plot_reference_ids': self.plot_reference_ids, 'python_function_names': self.python_function_names, 'project_name': self.project_name}
+        resp = {'name': self.name, 'graph_dashboard_id': self.graph_dashboard_id, 'created_at': self.created_at, 'project_id': self.project_id, 'python_function_ids': self.python_function_ids,
+                'plot_reference_ids': self.plot_reference_ids, 'python_function_names': self.python_function_names, 'project_name': self.project_name, 'description': self.description}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
 
     def refresh(self):
         """
@@ -71,13 +83,13 @@ class GraphDashboard(AbstractApiClass):
         """
         return self.client.delete_graph_dashboard(self.graph_dashboard_id)
 
-    def update(self, name: str = None, python_function_ids: list = None):
+    def update(self, name: str = None, python_function_ids: List = None):
         """
         Updates a graph dashboard
 
         Args:
             name (str): Name of the dashboard.
-            python_function_ids (list): List of unique string identifiers for the Python functions to be used in the graph dashboard.
+            python_function_ids (List): List of unique string identifiers for the Python functions to be used in the graph dashboard.
 
         Returns:
             GraphDashboard: An object describing the graph dashboard.
