@@ -17,9 +17,15 @@ class IndexingConfig(AbstractApiClass):
         self.primary_key = primaryKey
         self.update_timestamp_key = updateTimestampKey
         self.lookup_keys = lookupKeys
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"IndexingConfig(primary_key={repr(self.primary_key)},\n  update_timestamp_key={repr(self.update_timestamp_key)},\n  lookup_keys={repr(self.lookup_keys)})"
+        repr_dict = {f'primary_key': repr(self.primary_key), f'update_timestamp_key': repr(
+            self.update_timestamp_key), f'lookup_keys': repr(self.lookup_keys)}
+        class_name = "IndexingConfig"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -28,4 +34,6 @@ class IndexingConfig(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'primary_key': self.primary_key, 'update_timestamp_key': self.update_timestamp_key, 'lookup_keys': self.lookup_keys}
+        resp = {'primary_key': self.primary_key, 'update_timestamp_key':
+                self.update_timestamp_key, 'lookup_keys': self.lookup_keys}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
