@@ -15,9 +15,15 @@ class ModelLocation(AbstractApiClass):
         super().__init__(client, None)
         self.location = location
         self.artifact_names = artifactNames
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"ModelLocation(location={repr(self.location)},\n  artifact_names={repr(self.artifact_names)})"
+        repr_dict = {f'location': repr(
+            self.location), f'artifact_names': repr(self.artifact_names)}
+        class_name = "ModelLocation"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -26,4 +32,6 @@ class ModelLocation(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'location': self.location, 'artifact_names': self.artifact_names}
+        resp = {'location': self.location,
+                'artifact_names': self.artifact_names}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
