@@ -15,9 +15,14 @@ class ModelMonitorSummaryFromOrg(AbstractApiClass):
         super().__init__(client, None)
         self.data = data
         self.infos = infos
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"ModelMonitorSummaryFromOrg(data={repr(self.data)},\n  infos={repr(self.infos)})"
+        repr_dict = {f'data': repr(self.data), f'infos': repr(self.infos)}
+        class_name = "ModelMonitorSummaryFromOrg"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -26,4 +31,5 @@ class ModelMonitorSummaryFromOrg(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'data': self.data, 'infos': self.infos}
+        resp = {'data': self.data, 'infos': self.infos}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
