@@ -23,9 +23,15 @@ class ModelMonitorVersion(AbstractApiClass):
             modelVersion (list[str]): Model version IDs that this refresh pipeline run is monitoring.
             batchPredictionVersion (str): The batch prediction version this model monitor is monitoring
             edaConfigs (list): The list of eda configs for the version
+            trainingForecastConfig (dict): The training forecast config for the monitor version
+            predictionForecastConfig (dict): The prediction forecast config for the monitor version
+            forecastFrequency (str): The forecast frequency for the monitor version
+            monitorDriftConfig (dict): The monitor drift config for the monitor version
+            predictionDataUseMappings (dict): The mapping of prediction data use to feature group version
+            trainingDataUseMappings (dict): The mapping of training data use to feature group version
     """
 
-    def __init__(self, client, modelMonitorVersion=None, status=None, modelMonitorId=None, monitoringStartedAt=None, monitoringCompletedAt=None, trainingFeatureGroupVersion=None, predictionFeatureGroupVersion=None, error=None, pendingDeploymentIds=None, failedDeploymentIds=None, metricConfigs=None, featureGroupMonitorConfigs=None, metricTypes=None, modelVersion=None, batchPredictionVersion=None, edaConfigs=None):
+    def __init__(self, client, modelMonitorVersion=None, status=None, modelMonitorId=None, monitoringStartedAt=None, monitoringCompletedAt=None, trainingFeatureGroupVersion=None, predictionFeatureGroupVersion=None, error=None, pendingDeploymentIds=None, failedDeploymentIds=None, metricConfigs=None, featureGroupMonitorConfigs=None, metricTypes=None, modelVersion=None, batchPredictionVersion=None, edaConfigs=None, trainingForecastConfig=None, predictionForecastConfig=None, forecastFrequency=None, monitorDriftConfig=None, predictionDataUseMappings=None, trainingDataUseMappings=None):
         super().__init__(client, modelMonitorVersion)
         self.model_monitor_version = modelMonitorVersion
         self.status = status
@@ -43,9 +49,21 @@ class ModelMonitorVersion(AbstractApiClass):
         self.model_version = modelVersion
         self.batch_prediction_version = batchPredictionVersion
         self.eda_configs = edaConfigs
+        self.training_forecast_config = trainingForecastConfig
+        self.prediction_forecast_config = predictionForecastConfig
+        self.forecast_frequency = forecastFrequency
+        self.monitor_drift_config = monitorDriftConfig
+        self.prediction_data_use_mappings = predictionDataUseMappings
+        self.training_data_use_mappings = trainingDataUseMappings
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"ModelMonitorVersion(model_monitor_version={repr(self.model_monitor_version)},\n  status={repr(self.status)},\n  model_monitor_id={repr(self.model_monitor_id)},\n  monitoring_started_at={repr(self.monitoring_started_at)},\n  monitoring_completed_at={repr(self.monitoring_completed_at)},\n  training_feature_group_version={repr(self.training_feature_group_version)},\n  prediction_feature_group_version={repr(self.prediction_feature_group_version)},\n  error={repr(self.error)},\n  pending_deployment_ids={repr(self.pending_deployment_ids)},\n  failed_deployment_ids={repr(self.failed_deployment_ids)},\n  metric_configs={repr(self.metric_configs)},\n  feature_group_monitor_configs={repr(self.feature_group_monitor_configs)},\n  metric_types={repr(self.metric_types)},\n  model_version={repr(self.model_version)},\n  batch_prediction_version={repr(self.batch_prediction_version)},\n  eda_configs={repr(self.eda_configs)})"
+        repr_dict = {f'model_monitor_version': repr(self.model_monitor_version), f'status': repr(self.status), f'model_monitor_id': repr(self.model_monitor_id), f'monitoring_started_at': repr(self.monitoring_started_at), f'monitoring_completed_at': repr(self.monitoring_completed_at), f'training_feature_group_version': repr(self.training_feature_group_version), f'prediction_feature_group_version': repr(self.prediction_feature_group_version), f'error': repr(self.error), f'pending_deployment_ids': repr(self.pending_deployment_ids), f'failed_deployment_ids': repr(self.failed_deployment_ids), f'metric_configs': repr(self.metric_configs), f'feature_group_monitor_configs': repr(
+            self.feature_group_monitor_configs), f'metric_types': repr(self.metric_types), f'model_version': repr(self.model_version), f'batch_prediction_version': repr(self.batch_prediction_version), f'eda_configs': repr(self.eda_configs), f'training_forecast_config': repr(self.training_forecast_config), f'prediction_forecast_config': repr(self.prediction_forecast_config), f'forecast_frequency': repr(self.forecast_frequency), f'monitor_drift_config': repr(self.monitor_drift_config), f'prediction_data_use_mappings': repr(self.prediction_data_use_mappings), f'training_data_use_mappings': repr(self.training_data_use_mappings)}
+        class_name = "ModelMonitorVersion"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -54,7 +72,9 @@ class ModelMonitorVersion(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'model_monitor_version': self.model_monitor_version, 'status': self.status, 'model_monitor_id': self.model_monitor_id, 'monitoring_started_at': self.monitoring_started_at, 'monitoring_completed_at': self.monitoring_completed_at, 'training_feature_group_version': self.training_feature_group_version, 'prediction_feature_group_version': self.prediction_feature_group_version, 'error': self.error, 'pending_deployment_ids': self.pending_deployment_ids, 'failed_deployment_ids': self.failed_deployment_ids, 'metric_configs': self.metric_configs, 'feature_group_monitor_configs': self.feature_group_monitor_configs, 'metric_types': self.metric_types, 'model_version': self.model_version, 'batch_prediction_version': self.batch_prediction_version, 'eda_configs': self.eda_configs}
+        resp = {'model_monitor_version': self.model_monitor_version, 'status': self.status, 'model_monitor_id': self.model_monitor_id, 'monitoring_started_at': self.monitoring_started_at, 'monitoring_completed_at': self.monitoring_completed_at, 'training_feature_group_version': self.training_feature_group_version, 'prediction_feature_group_version': self.prediction_feature_group_version, 'error': self.error, 'pending_deployment_ids': self.pending_deployment_ids, 'failed_deployment_ids': self.failed_deployment_ids, 'metric_configs': self.metric_configs,
+                'feature_group_monitor_configs': self.feature_group_monitor_configs, 'metric_types': self.metric_types, 'model_version': self.model_version, 'batch_prediction_version': self.batch_prediction_version, 'eda_configs': self.eda_configs, 'training_forecast_config': self.training_forecast_config, 'prediction_forecast_config': self.prediction_forecast_config, 'forecast_frequency': self.forecast_frequency, 'monitor_drift_config': self.monitor_drift_config, 'prediction_data_use_mappings': self.prediction_data_use_mappings, 'training_data_use_mappings': self.training_data_use_mappings}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
 
     def get_prediction_drift(self):
         """
@@ -120,23 +140,10 @@ class ModelMonitorVersion(AbstractApiClass):
             model_monitor_version (str): The unique ID associated with the model monitor.
 
         Returns:
-            MonitorAlertVersion: A list of monitor alert versions.
+            list[MonitorAlertVersion]: A list of monitor alert versions.
         """
         return self.client.list_monitor_alert_versions_for_monitor_version(self.model_monitor_version)
 
-    def get_model_monitoring_logs(self, stdout: bool = False, stderr: bool = False):
-        """
-        Returns monitoring logs for the model.
-
-        Args:
-            stdout (bool): Set True to get info logs
-            stderr (bool): Set True to get error logs
-
-        Returns:
-            FunctionLogs: A function logs.
-        """
-        return self.client.get_model_monitoring_logs(self.model_monitor_version, stdout, stderr)
-
     def get_drift_for_feature(self, feature_name: str, nested_feature_name: str = None):
         """
         Gets the feature drift associated with a single feature in an output feature group from a prediction.
@@ -144,6 +151,9 @@ class ModelMonitorVersion(AbstractApiClass):
         Args:
             feature_name (str): Name of the feature to view the distribution of.
             nested_feature_name (str): Optionally, the name of the nested feature that the feature is in.
+
+        Returns:
+            FeatureDistribution: An object describing the training and prediction output feature distributions.
         """
         return self.client.get_drift_for_feature(self.model_monitor_version, feature_name, nested_feature_name)
 
@@ -162,7 +172,7 @@ class ModelMonitorVersion(AbstractApiClass):
         A waiting call until model monitor version is ready.
 
         Args:
-            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
+            timeout (int): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
         """
         return self.client._poll(self, {'PENDING', 'MONITORING'}, timeout=timeout)
 
