@@ -15,9 +15,14 @@ class ModelTrainingTypeForDeployment(AbstractApiClass):
         super().__init__(client, None)
         self.label = label
         self.value = value
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"ModelTrainingTypeForDeployment(label={repr(self.label)},\n  value={repr(self.value)})"
+        repr_dict = {f'label': repr(self.label), f'value': repr(self.value)}
+        class_name = "ModelTrainingTypeForDeployment"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -26,4 +31,5 @@ class ModelTrainingTypeForDeployment(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'label': self.label, 'value': self.value}
+        resp = {'label': self.label, 'value': self.value}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
