@@ -25,9 +25,10 @@ class MonitorAlertVersion(AbstractApiClass):
             actionCompletedAt (str): The end time and date of the actionfor the alerting process.
             conditionDescription (str): User friendly description of the condition
             actionDescription (str): User friendly description of the action
+            alertType (str): The type of the alert
     """
 
-    def __init__(self, client, name=None, monitorAlertVersion=None, monitorAlertId=None, status=None, createdAt=None, alertingStartedAt=None, alertingCompletedAt=None, error=None, modelMonitorVersion=None, conditionConfig=None, actionConfig=None, alertResult=None, actionStatus=None, actionError=None, actionStartedAt=None, actionCompletedAt=None, conditionDescription=None, actionDescription=None):
+    def __init__(self, client, name=None, monitorAlertVersion=None, monitorAlertId=None, status=None, createdAt=None, alertingStartedAt=None, alertingCompletedAt=None, error=None, modelMonitorVersion=None, conditionConfig=None, actionConfig=None, alertResult=None, actionStatus=None, actionError=None, actionStartedAt=None, actionCompletedAt=None, conditionDescription=None, actionDescription=None, alertType=None):
         super().__init__(client, monitorAlertVersion)
         self.name = name
         self.monitor_alert_version = monitorAlertVersion
@@ -47,9 +48,16 @@ class MonitorAlertVersion(AbstractApiClass):
         self.action_completed_at = actionCompletedAt
         self.condition_description = conditionDescription
         self.action_description = actionDescription
+        self.alert_type = alertType
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"MonitorAlertVersion(name={repr(self.name)},\n  monitor_alert_version={repr(self.monitor_alert_version)},\n  monitor_alert_id={repr(self.monitor_alert_id)},\n  status={repr(self.status)},\n  created_at={repr(self.created_at)},\n  alerting_started_at={repr(self.alerting_started_at)},\n  alerting_completed_at={repr(self.alerting_completed_at)},\n  error={repr(self.error)},\n  model_monitor_version={repr(self.model_monitor_version)},\n  condition_config={repr(self.condition_config)},\n  action_config={repr(self.action_config)},\n  alert_result={repr(self.alert_result)},\n  action_status={repr(self.action_status)},\n  action_error={repr(self.action_error)},\n  action_started_at={repr(self.action_started_at)},\n  action_completed_at={repr(self.action_completed_at)},\n  condition_description={repr(self.condition_description)},\n  action_description={repr(self.action_description)})"
+        repr_dict = {f'name': repr(self.name), f'monitor_alert_version': repr(self.monitor_alert_version), f'monitor_alert_id': repr(self.monitor_alert_id), f'status': repr(self.status), f'created_at': repr(self.created_at), f'alerting_started_at': repr(self.alerting_started_at), f'alerting_completed_at': repr(self.alerting_completed_at), f'error': repr(self.error), f'model_monitor_version': repr(self.model_monitor_version), f'condition_config': repr(
+            self.condition_config), f'action_config': repr(self.action_config), f'alert_result': repr(self.alert_result), f'action_status': repr(self.action_status), f'action_error': repr(self.action_error), f'action_started_at': repr(self.action_started_at), f'action_completed_at': repr(self.action_completed_at), f'condition_description': repr(self.condition_description), f'action_description': repr(self.action_description), f'alert_type': repr(self.alert_type)}
+        class_name = "MonitorAlertVersion"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -58,7 +66,9 @@ class MonitorAlertVersion(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'name': self.name, 'monitor_alert_version': self.monitor_alert_version, 'monitor_alert_id': self.monitor_alert_id, 'status': self.status, 'created_at': self.created_at, 'alerting_started_at': self.alerting_started_at, 'alerting_completed_at': self.alerting_completed_at, 'error': self.error, 'model_monitor_version': self.model_monitor_version, 'condition_config': self.condition_config, 'action_config': self.action_config, 'alert_result': self.alert_result, 'action_status': self.action_status, 'action_error': self.action_error, 'action_started_at': self.action_started_at, 'action_completed_at': self.action_completed_at, 'condition_description': self.condition_description, 'action_description': self.action_description}
+        resp = {'name': self.name, 'monitor_alert_version': self.monitor_alert_version, 'monitor_alert_id': self.monitor_alert_id, 'status': self.status, 'created_at': self.created_at, 'alerting_started_at': self.alerting_started_at, 'alerting_completed_at': self.alerting_completed_at, 'error': self.error, 'model_monitor_version': self.model_monitor_version, 'condition_config': self.condition_config,
+                'action_config': self.action_config, 'alert_result': self.alert_result, 'action_status': self.action_status, 'action_error': self.action_error, 'action_started_at': self.action_started_at, 'action_completed_at': self.action_completed_at, 'condition_description': self.condition_description, 'action_description': self.action_description, 'alert_type': self.alert_type}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
 
     def refresh(self):
         """
@@ -87,7 +97,7 @@ class MonitorAlertVersion(AbstractApiClass):
         A waiting call until model monitor version is ready.
 
         Args:
-            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
+            timeout (int): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
         """
         return self.client._poll(self, {'PENDING', 'RUNNING'}, timeout=timeout)
 
