@@ -21,9 +21,15 @@ class NotebookCompletion(AbstractApiClass):
         self.mode = mode
         self.index = index
         self.prompts = prompts
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"NotebookCompletion(cell_type={repr(self.cell_type)},\n  content={repr(self.content)},\n  mode={repr(self.mode)},\n  index={repr(self.index)},\n  prompts={repr(self.prompts)})"
+        repr_dict = {f'cell_type': repr(self.cell_type), f'content': repr(self.content), f'mode': repr(
+            self.mode), f'index': repr(self.index), f'prompts': repr(self.prompts)}
+        class_name = "NotebookCompletion"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -32,4 +38,6 @@ class NotebookCompletion(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'cell_type': self.cell_type, 'content': self.content, 'mode': self.mode, 'index': self.index, 'prompts': self.prompts}
+        resp = {'cell_type': self.cell_type, 'content': self.content,
+                'mode': self.mode, 'index': self.index, 'prompts': self.prompts}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
