@@ -21,9 +21,15 @@ class PredictionDataset(AbstractApiClass):
         self.dataset_version = datasetVersion
         self.default = default
         self.required = required
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"PredictionDataset(dataset_id={repr(self.dataset_id)},\n  dataset_type={repr(self.dataset_type)},\n  dataset_version={repr(self.dataset_version)},\n  default={repr(self.default)},\n  required={repr(self.required)})"
+        repr_dict = {f'dataset_id': repr(self.dataset_id), f'dataset_type': repr(self.dataset_type), f'dataset_version': repr(
+            self.dataset_version), f'default': repr(self.default), f'required': repr(self.required)}
+        class_name = "PredictionDataset"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -32,4 +38,6 @@ class PredictionDataset(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'dataset_id': self.dataset_id, 'dataset_type': self.dataset_type, 'dataset_version': self.dataset_version, 'default': self.default, 'required': self.required}
+        resp = {'dataset_id': self.dataset_id, 'dataset_type': self.dataset_type,
+                'dataset_version': self.dataset_version, 'default': self.default, 'required': self.required}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
