@@ -21,9 +21,15 @@ class PredictionFeatureGroup(AbstractApiClass):
         self.dataset_type = datasetType
         self.default = default
         self.required = required
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"PredictionFeatureGroup(feature_group_id={repr(self.feature_group_id)},\n  feature_group_version={repr(self.feature_group_version)},\n  dataset_type={repr(self.dataset_type)},\n  default={repr(self.default)},\n  required={repr(self.required)})"
+        repr_dict = {f'feature_group_id': repr(self.feature_group_id), f'feature_group_version': repr(
+            self.feature_group_version), f'dataset_type': repr(self.dataset_type), f'default': repr(self.default), f'required': repr(self.required)}
+        class_name = "PredictionFeatureGroup"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -32,4 +38,6 @@ class PredictionFeatureGroup(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'feature_group_id': self.feature_group_id, 'feature_group_version': self.feature_group_version, 'dataset_type': self.dataset_type, 'default': self.default, 'required': self.required}
+        resp = {'feature_group_id': self.feature_group_id, 'feature_group_version': self.feature_group_version,
+                'dataset_type': self.dataset_type, 'default': self.default, 'required': self.required}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
