@@ -22,9 +22,15 @@ class PredictionInput(AbstractApiClass):
         self.feature_groups = client._build_class(
             PredictionFeatureGroup, featureGroups)
         self.datasets = client._build_class(PredictionDataset, datasets)
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"PredictionInput(feature_group_dataset_ids={repr(self.feature_group_dataset_ids)},\n  dataset_id_remap={repr(self.dataset_id_remap)},\n  feature_groups={repr(self.feature_groups)},\n  datasets={repr(self.datasets)})"
+        repr_dict = {f'feature_group_dataset_ids': repr(self.feature_group_dataset_ids), f'dataset_id_remap': repr(
+            self.dataset_id_remap), f'feature_groups': repr(self.feature_groups), f'datasets': repr(self.datasets)}
+        class_name = "PredictionInput"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -33,4 +39,6 @@ class PredictionInput(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'feature_group_dataset_ids': self.feature_group_dataset_ids, 'dataset_id_remap': self.dataset_id_remap, 'feature_groups': self._get_attribute_as_dict(self.feature_groups), 'datasets': self._get_attribute_as_dict(self.datasets)}
+        resp = {'feature_group_dataset_ids': self.feature_group_dataset_ids, 'dataset_id_remap': self.dataset_id_remap,
+                'feature_groups': self._get_attribute_as_dict(self.feature_groups), 'datasets': self._get_attribute_as_dict(self.datasets)}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
