@@ -17,9 +17,15 @@ class ProjectValidation(AbstractApiClass):
         self.valid = valid
         self.dataset_errors = datasetErrors
         self.column_hints = columnHints
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"ProjectValidation(valid={repr(self.valid)},\n  dataset_errors={repr(self.dataset_errors)},\n  column_hints={repr(self.column_hints)})"
+        repr_dict = {f'valid': repr(self.valid), f'dataset_errors': repr(
+            self.dataset_errors), f'column_hints': repr(self.column_hints)}
+        class_name = "ProjectValidation"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -28,4 +34,6 @@ class ProjectValidation(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'valid': self.valid, 'dataset_errors': self.dataset_errors, 'column_hints': self.column_hints}
+        resp = {'valid': self.valid, 'dataset_errors': self.dataset_errors,
+                'column_hints': self.column_hints}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
