@@ -11,19 +11,25 @@ class RefreshSchedule(AbstractApiClass):
             nextRunTime (str): The next run time of the refresh policy. If null, the policy is paused.
             cron (str): A cron-style string that describes the when this refresh policy is to be executed in UTC
             refreshType (str): The type of refresh that will be run
-            lifecycleMsg (str): An error message for the last pipeline run of a policy
+            error (str): An error message for the last pipeline run of a policy
     """
 
-    def __init__(self, client, refreshPolicyId=None, nextRunTime=None, cron=None, refreshType=None, lifecycleMsg=None):
+    def __init__(self, client, refreshPolicyId=None, nextRunTime=None, cron=None, refreshType=None, error=None):
         super().__init__(client, None)
         self.refresh_policy_id = refreshPolicyId
         self.next_run_time = nextRunTime
         self.cron = cron
         self.refresh_type = refreshType
-        self.lifecycle_msg = lifecycleMsg
+        self.error = error
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"RefreshSchedule(refresh_policy_id={repr(self.refresh_policy_id)},\n  next_run_time={repr(self.next_run_time)},\n  cron={repr(self.cron)},\n  refresh_type={repr(self.refresh_type)},\n  lifecycle_msg={repr(self.lifecycle_msg)})"
+        repr_dict = {f'refresh_policy_id': repr(self.refresh_policy_id), f'next_run_time': repr(
+            self.next_run_time), f'cron': repr(self.cron), f'refresh_type': repr(self.refresh_type), f'error': repr(self.error)}
+        class_name = "RefreshSchedule"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -32,4 +38,6 @@ class RefreshSchedule(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'refresh_policy_id': self.refresh_policy_id, 'next_run_time': self.next_run_time, 'cron': self.cron, 'refresh_type': self.refresh_type, 'lifecycle_msg': self.lifecycle_msg}
+        resp = {'refresh_policy_id': self.refresh_policy_id, 'next_run_time': self.next_run_time,
+                'cron': self.cron, 'refresh_type': self.refresh_type, 'error': self.error}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
