@@ -21,9 +21,15 @@ class ResolvedFeatureGroupTemplate(AbstractApiClass):
         self.resolved_sql = resolvedSql
         self.template_sql = templateSql
         self.sql_error = sqlError
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"ResolvedFeatureGroupTemplate(feature_group_template_id={repr(self.feature_group_template_id)},\n  resolved_variables={repr(self.resolved_variables)},\n  resolved_sql={repr(self.resolved_sql)},\n  template_sql={repr(self.template_sql)},\n  sql_error={repr(self.sql_error)})"
+        repr_dict = {f'feature_group_template_id': repr(self.feature_group_template_id), f'resolved_variables': repr(
+            self.resolved_variables), f'resolved_sql': repr(self.resolved_sql), f'template_sql': repr(self.template_sql), f'sql_error': repr(self.sql_error)}
+        class_name = "ResolvedFeatureGroupTemplate"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -32,4 +38,6 @@ class ResolvedFeatureGroupTemplate(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'feature_group_template_id': self.feature_group_template_id, 'resolved_variables': self.resolved_variables, 'resolved_sql': self.resolved_sql, 'template_sql': self.template_sql, 'sql_error': self.sql_error}
+        resp = {'feature_group_template_id': self.feature_group_template_id, 'resolved_variables': self.resolved_variables,
+                'resolved_sql': self.resolved_sql, 'template_sql': self.template_sql, 'sql_error': self.sql_error}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
