@@ -17,3 +17,12 @@ class AbstractApiClass:
             return [elem.to_dict() for elem in attribute if elem]
         elif attribute is not None:
             return attribute.to_dict()
+
+    def __getattribute__(self, __name: str):
+        try:
+            return super().__getattribute__(__name)
+        except AttributeError as e:
+            attributes = {f"'{attr}'" for attr in self.__dict__.keys() if attr not in {
+                'client', 'deprecated_keys'}}
+            raise AttributeError(
+                f'{e}. Did you mean one of {", ".join(attributes)}?') from None
