@@ -15,9 +15,15 @@ class StreamingAuthToken(AbstractApiClass):
         super().__init__(client, None)
         self.streaming_token = streamingToken
         self.created_at = createdAt
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"StreamingAuthToken(streaming_token={repr(self.streaming_token)},\n  created_at={repr(self.created_at)})"
+        repr_dict = {f'streaming_token': repr(
+            self.streaming_token), f'created_at': repr(self.created_at)}
+        class_name = "StreamingAuthToken"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -26,4 +32,6 @@ class StreamingAuthToken(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'streaming_token': self.streaming_token, 'created_at': self.created_at}
+        resp = {'streaming_token': self.streaming_token,
+                'created_at': self.created_at}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
