@@ -23,9 +23,15 @@ class StreamingConnector(AbstractApiClass):
         self.created_at = createdAt
         self.status = status
         self.auth = auth
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"StreamingConnector(streaming_connector_id={repr(self.streaming_connector_id)},\n  service={repr(self.service)},\n  name={repr(self.name)},\n  created_at={repr(self.created_at)},\n  status={repr(self.status)},\n  auth={repr(self.auth)})"
+        repr_dict = {f'streaming_connector_id': repr(self.streaming_connector_id), f'service': repr(self.service), f'name': repr(
+            self.name), f'created_at': repr(self.created_at), f'status': repr(self.status), f'auth': repr(self.auth)}
+        class_name = "StreamingConnector"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -34,7 +40,9 @@ class StreamingConnector(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'streaming_connector_id': self.streaming_connector_id, 'service': self.service, 'name': self.name, 'created_at': self.created_at, 'status': self.status, 'auth': self.auth}
+        resp = {'streaming_connector_id': self.streaming_connector_id, 'service': self.service,
+                'name': self.name, 'created_at': self.created_at, 'status': self.status, 'auth': self.auth}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
 
     def verify(self):
         """
