@@ -11,9 +11,9 @@ class TrainingConfigOptions(AbstractApiClass):
             dataType (str): The type of input required for this option
             valueType (str): If the data_type is of type DICT_VALUES, this field specifies the expected value type of the values
             valueOptions (list[str]): The list of valid values for DICT_VALUES
-            value (optional[str, int, float, bool]): The value of this option
-            default (optional[str, int, float, bool]): The default value for this option
-            options (list[dict]): A list of options for this parameter
+            value (optional[any]): The value of this option
+            default (optional[any]): The default value for this option
+            options (dict): A dict of options for this parameter
             description (str): A description of the parameter
             required (bool): True if the parameter is required for training
             lastModelValue (optional[str, int, float, bool]): The last value used to train a model in this project
@@ -33,9 +33,15 @@ class TrainingConfigOptions(AbstractApiClass):
         self.required = required
         self.last_model_value = lastModelValue
         self.needs_refresh = needsRefresh
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"TrainingConfigOptions(name={repr(self.name)},\n  data_type={repr(self.data_type)},\n  value_type={repr(self.value_type)},\n  value_options={repr(self.value_options)},\n  value={repr(self.value)},\n  default={repr(self.default)},\n  options={repr(self.options)},\n  description={repr(self.description)},\n  required={repr(self.required)},\n  last_model_value={repr(self.last_model_value)},\n  needs_refresh={repr(self.needs_refresh)})"
+        repr_dict = {f'name': repr(self.name), f'data_type': repr(self.data_type), f'value_type': repr(self.value_type), f'value_options': repr(self.value_options), f'value': repr(self.value), f'default': repr(
+            self.default), f'options': repr(self.options), f'description': repr(self.description), f'required': repr(self.required), f'last_model_value': repr(self.last_model_value), f'needs_refresh': repr(self.needs_refresh)}
+        class_name = "TrainingConfigOptions"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -44,4 +50,6 @@ class TrainingConfigOptions(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'name': self.name, 'data_type': self.data_type, 'value_type': self.value_type, 'value_options': self.value_options, 'value': self.value, 'default': self.default, 'options': self.options, 'description': self.description, 'required': self.required, 'last_model_value': self.last_model_value, 'needs_refresh': self.needs_refresh}
+        resp = {'name': self.name, 'data_type': self.data_type, 'value_type': self.value_type, 'value_options': self.value_options, 'value': self.value, 'default': self.default,
+                'options': self.options, 'description': self.description, 'required': self.required, 'last_model_value': self.last_model_value, 'needs_refresh': self.needs_refresh}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
