@@ -15,9 +15,14 @@ class UploadPart(AbstractApiClass):
         super().__init__(client, None)
         self.etag = etag
         self.md5 = md5
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"UploadPart(etag={repr(self.etag)},\n  md5={repr(self.md5)})"
+        repr_dict = {f'etag': repr(self.etag), f'md5': repr(self.md5)}
+        class_name = "UploadPart"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -26,4 +31,5 @@ class UploadPart(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'etag': self.etag, 'md5': self.md5}
+        resp = {'etag': self.etag, 'md5': self.md5}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
