@@ -19,9 +19,15 @@ class UseCase(AbstractApiClass):
         self.pretty_name = prettyName
         self.description = description
         self.problem_type = problemType
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"UseCase(use_case={repr(self.use_case)},\n  pretty_name={repr(self.pretty_name)},\n  description={repr(self.description)},\n  problem_type={repr(self.problem_type)})"
+        repr_dict = {f'use_case': repr(self.use_case), f'pretty_name': repr(
+            self.pretty_name), f'description': repr(self.description), f'problem_type': repr(self.problem_type)}
+        class_name = "UseCase"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -30,4 +36,6 @@ class UseCase(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'use_case': self.use_case, 'pretty_name': self.pretty_name, 'description': self.description, 'problem_type': self.problem_type}
+        resp = {'use_case': self.use_case, 'pretty_name': self.pretty_name,
+                'description': self.description, 'problem_type': self.problem_type}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
