@@ -23,9 +23,15 @@ class User(AbstractApiClass):
         self.status = status
         self.organization_groups = client._build_class(
             OrganizationGroup, organizationGroups)
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"User(name={repr(self.name)},\n  email={repr(self.email)},\n  created_at={repr(self.created_at)},\n  status={repr(self.status)},\n  organization_groups={repr(self.organization_groups)})"
+        repr_dict = {f'name': repr(self.name), f'email': repr(self.email), f'created_at': repr(
+            self.created_at), f'status': repr(self.status), f'organization_groups': repr(self.organization_groups)}
+        class_name = "User"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -34,4 +40,6 @@ class User(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'name': self.name, 'email': self.email, 'created_at': self.created_at, 'status': self.status, 'organization_groups': self._get_attribute_as_dict(self.organization_groups)}
+        resp = {'name': self.name, 'email': self.email, 'created_at': self.created_at, 'status': self.status,
+                'organization_groups': self._get_attribute_as_dict(self.organization_groups)}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
