@@ -19,9 +19,15 @@ class UserException(AbstractApiClass):
         self.type = type
         self.value = value
         self.traceback = traceback
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"UserException(type={repr(self.type)},\n  value={repr(self.value)},\n  traceback={'[91m' + ((chr(39) * 3 + chr(10) + textwrap.indent(self.traceback, ' ' * 6) + chr(39) * 3) if self.traceback else str(self.traceback)) + '[0;0m'})"
+        repr_dict = {f'type': repr(self.type), f'value': repr(self.value), f'traceback': '[91m' + ((chr(39) * 3 + chr(
+            10) + textwrap.indent(self.traceback, ' ' * 6) + chr(39) * 3) if self.traceback else str(self.traceback)) + '[0;0m'}
+        class_name = "UserException"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -30,4 +36,6 @@ class UserException(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'type': self.type, 'value': self.value, 'traceback': self.traceback}
+        resp = {'type': self.type, 'value': self.value,
+                'traceback': self.traceback}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
