@@ -23,9 +23,15 @@ class Webhook(AbstractApiClass):
         self.webhook_event_type = webhookEventType
         self.payload_template = payloadTemplate
         self.created_at = createdAt
+        self.deprecated_keys = {}
 
     def __repr__(self):
-        return f"Webhook(webhook_id={repr(self.webhook_id)},\n  deployment_id={repr(self.deployment_id)},\n  endpoint={repr(self.endpoint)},\n  webhook_event_type={repr(self.webhook_event_type)},\n  payload_template={repr(self.payload_template)},\n  created_at={repr(self.created_at)})"
+        repr_dict = {f'webhook_id': repr(self.webhook_id), f'deployment_id': repr(self.deployment_id), f'endpoint': repr(self.endpoint), f'webhook_event_type': repr(
+            self.webhook_event_type), f'payload_template': repr(self.payload_template), f'created_at': repr(self.created_at)}
+        class_name = "Webhook"
+        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
+        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
+        return f"{class_name}({repr_str})"
 
     def to_dict(self):
         """
@@ -34,7 +40,9 @@ class Webhook(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'webhook_id': self.webhook_id, 'deployment_id': self.deployment_id, 'endpoint': self.endpoint, 'webhook_event_type': self.webhook_event_type, 'payload_template': self.payload_template, 'created_at': self.created_at}
+        resp = {'webhook_id': self.webhook_id, 'deployment_id': self.deployment_id, 'endpoint': self.endpoint,
+                'webhook_event_type': self.webhook_event_type, 'payload_template': self.payload_template, 'created_at': self.created_at}
+        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
 
     def refresh(self):
         """
